
<br><br><br><br>
<div class=" h-[827px] flex flex-col items-center md:flex-row justify-center md:justify-start px-4 md:px-[200px] md:bg-center bg-right bg-cover bg-no-repeat "
    style="background-image: url('{{ asset('./images/background/bg-1.png') }}');">
    <div class="  flex flex-col md:items-start justify-center items-center w-full md:w-[40%] w-[100%] mt-4 md:mt-0"
        data-aos="fade-up">

        <x-header-section subtext="GALLERY {{ $settings['nama kampus'] ?? 'Nama kampus tidak tersedia' }}" subtext-color="#30c906" title=" " title-color="#30c906" />
        <div class=" swiper mySwiper mb-3 mb-[50px] md:w-[1300px] w-full">
            <div class="swiper-wrapper">
                @foreach ($images as $index => $image)
                    <div class="swiper-slide">
                        <img src="{{ asset('./storage/galleryFoto/' . $image->file) }}" />
                    </div>
                @endforeach
            </div>
            <div class="swiper-pagination"></div>
        </div>
        <a href="/pendaftaran" class="bg-yellow-400 hover:bg-primary font-medium py-2 px-3 rounded-md text-sm transition-all text-center text-white">PENDAFTARAN ONLINE </a>
</div>
</div>
